@@ -1,5 +1,7 @@
-from pydantic import BaseSettings
+from pydantic import BaseSettings, Field
 from nonebot import get_driver
+from typing import List, Optional
+
 from nonebot.rule import to_me
 import yaml
 from pathlib import Path
@@ -7,11 +9,14 @@ from pathlib import Path
 class Config(BaseSettings):
     # Your Config Here
     gpt3_api_key_path: str = "config/chatgpt_api_key.yml"
+    gpt3_api_key_list_from_env: Optional[list] = Field(default_factory=list)
     gpt3_command_prefix: str = 'gpt3'
     gpt3_need_at: bool = False
     gpt3_image_render: bool = False
     gpt3_image_limit: int = 100
     gpt3_max_tokens: int = 400
+    gpt3_model : str = 'text-davinci-003'
+    gpt3_chat_count_per_day: int = 100
 
 
     class Config:
@@ -27,7 +32,9 @@ gpt3_need_at = config.gpt3_need_at
 gpt3_image_render = config.gpt3_image_render
 gpt3_image_limit = config.gpt3_image_limit
 gpt3_max_tokens = config.gpt3_max_tokens
-
+gpt3_model = config.gpt3_model
+gpt3_api_key_list_from_env = config.gpt3_api_key_list_from_env
+gpt3_chat_count_per_day = config.gpt3_chat_count_per_day
 
 # 如果不存在则创建
 LOCAL = Path() / "config"
@@ -38,9 +45,10 @@ if not Path(gpt3_api_key_path).exists():
 
 with open(gpt3_api_key_path, 'r', encoding='utf-8') as f:
     api_key_list = yaml.load(f, Loader=yaml.FullLoader).get('api_keys')
-
+    if len(api_key_list) == 0:
+        api_key_list = gpt3_api_key_list_from_env
 from nonebot.log import logger
-logger.info(f"加载 {len(api_key_list)}个 APIKeys")
+logger.info(f"加载 {len(api_key_list)}个 APIKeys {api_key_list}")
 
 # 基本会话
 matcher_params = {}
